@@ -1,11 +1,11 @@
-#### findPoisVar ####
+#### .findPoisVar ####
 
 # Internal function to find variance associated with ICC
 #
 # @param j Value of function
 # @return inverse of Poisson ICC function
 
-findPoisVar <- function(j) {
+.findPoisVar <- function(j) {
   
   # 'declare' var
   
@@ -29,4 +29,4 @@ findPoisVar <- function(j) {
   
   return(dx[y <= j][.N, a])
   
-}
\ No newline at end of file
+}
