@@ -1,6 +1,6 @@
 #### Normal distribution ####
 
-# Internal function called by generate - returns Normal data
+# Internal function called by .generate - returns Normal data
 #
 # @param n The number of observations required in the data set
 # @param forumula String that specifies the formula for the mean
@@ -9,7 +9,7 @@
 # @param dtSim Incomplete simulated data.table
 # @return A data.frame column  with the updated simulated data
 
-getNormalMean <- function(dtSim, formula) {
+.getNormalMean <- function(dtSim, formula) {
 
   mean <- with(dtSim, eval(parse(text = as.character(formula))))
 
@@ -17,9 +17,9 @@ getNormalMean <- function(dtSim, formula) {
 
 }
 
-gennorm <- function(n,formula,variance,link,dtSim) {
+.gennorm <- function(n,formula,variance,link,dtSim) {
 
-  mean <- getNormalMean(dtSim, formula)
+  mean <- .getNormalMean(dtSim, formula)
   v <- with(dtSim, eval(parse(text = as.character(variance))))
 
   return(stats::rnorm(n, mean, sqrt(v)))
